struct IntermediateComputedKeyframe {
declarations: PropertyDeclarationBlock,
timing_function: Option<TimingFunction>,
start_percentage: f32,
}Expand description
A temporary data structure used when calculating ComputedKeyframes for an
animation. This data structure is used to collapse information for steps
which may be spread across multiple keyframe declarations into a single
instance per start_percentage.
Fields
declarations: PropertyDeclarationBlocktiming_function: Option<TimingFunction>start_percentage: f32Implementations
Sourceimpl IntermediateComputedKeyframe
impl IntermediateComputedKeyframe
fn new(start_percentage: f32) -> Self
Sourcefn generate_for_keyframes(
animation: &KeyframesAnimation,
context: &SharedStyleContext<'_>,
base_style: &ComputedValues,
) -> Vec<Self>
fn generate_for_keyframes( animation: &KeyframesAnimation, context: &SharedStyleContext<'_>, base_style: &ComputedValues, ) -> Vec<Self>
Walk through all keyframe declarations and combine all declarations with the
same start_percentage into individual IntermediateComputedKeyframes.
fn update_from_step( &mut self, step: &KeyframesStep, context: &SharedStyleContext<'_>, base_style: &ComputedValues, )
fn resolve_style<E>(
self,
element: E,
context: &SharedStyleContext<'_>,
base_style: &Arc<ComputedValues>,
resolver: &mut StyleResolverForElement<'_, '_, '_, E>,
) -> Arc<ComputedValues>where
E: TElement,