struct PropertyDeclarationOffsets {
preceding_declaration: usize,
following_declaration: usize,
}Fields
preceding_declaration: usizeThe absolute index of the most recent preceding keyframe that declared the given property.
following_declaration: usizeThe absolute index of the next keyframe that will declare the given property.