struct KeyframeOffsetCacheForProperty {
last_keyframe_that_defined_property: usize,
next_keyframe_that_defines_property: Option<usize>,
}Expand description
Caches the indices of keyframes that declare a specific property.
While traversing the list of keyframes, this is used to avoid repeatedly searching for the next or last keyframe that declares the property. That would result in quadratic runtime with respect to the number of keyframes.
Fields
last_keyframe_that_defined_property: usizeThe index of a previous keyframe that declares the property.
Note that if the first keyframe does not declare a property, then it implicitly uses the computed value of that property. That’s why there’s always a preceding keyframe with the property.
next_keyframe_that_defines_property: Option<usize>The index of a future keyframe or None if we have not yet walked the list of keyframes
to find the next index.
There will always be a next keyframe because the last keyframe (like the first keyframe) declares all animating properties.